@@ -8,6 +8,8 @@ use crate::auth::AuthType;
 use crate::processor::Processor;
 use crate::utils::Utils;
 use crate::models::{CommentType, DiffOption};
+#[cfg(feature = "signature")]
+use crate::models::SignatureType;
 use std::path::{Path, PathBuf};
 
 /// Struct to parse command line arguments and execute proper operations
@@ -104,7 +106,16 @@ impl Cli {
             for file in files {
                 processor.from_file(Path::new(file))?;
             }
+            #[cfg(feature = "signature")]
+            self.print_signature(args, &mut processor)?;
         } else { // -->> Read from stdin
+
+            // Print signature if such option is given
+            // Signature option doesn't go with stdin option
+            #[cfg(feature = "signature")]
+            if self.print_signature(args, &mut processor)? {
+                return Ok(());
+            }
             processor.from_stdin()?;
         }
 
@@ -115,10 +126,18 @@ impl Cli {
         if let Some(file) = args.value_of("freeze") {
             processor.freeze_to_file(Path::new(file))?;
         }
+        Ok(())
+    }
 
+    /// Print signature
+    ///
+    /// Returns whether signature operation was executed or not
+    #[cfg(feature = "signature")]
+    fn print_signature(&mut self, args: &clap::ArgMatches, processor: &mut Processor) -> RadResult<bool> {
         #[cfg(feature = "signature")]
         if args.occurrences_of("signature") != 0 {
-            let sig_map = processor.get_signature_map()?;
+            let sig_type = SignatureType::from_str(args.value_of("sigtype").unwrap_or("all"))?;
+            let sig_map = processor.get_signature_map(sig_type)?;
             // TODO
             let sig_json = serde_json::to_string(&sig_map.object).expect("Failed to create sig map");
 
@@ -131,12 +150,12 @@ impl Cli {
             } else {
                 println!("{}", &sig_json);
             }
-        }
-        Ok(())
+            Ok(true)
+        } else { Ok(false) }
     }
 
     /// Parse processor options
-    fn parse_options(&mut self, args: & clap::ArgMatches) {
+    fn parse_options(&mut self, args: &clap::ArgMatches) {
         // ========
         // Sub options
         // custom rules
@@ -193,7 +212,7 @@ impl Cli {
     fn args_builder() -> clap::ArgMatches {
         use clap::{App,Arg};
         let app = App::new("rad")
-            .version("1.3.0")
+            .version("1.4.0")
             .author("Simon creek <simoncreek@tutanota.com>")
             .about( "R4d(rad) is a modern macro processor made with rust. Refer https://github.com/simhyeon/r4d for detailed usage.")
             .long_about("R4d is a text oriented macro processor which aims to be an modern alternative to m4 macro processor. R4d procedurally follows texts and substitue macro calls with defined macro body. R4d comes with varoius useful built in macros so that user don't have to define from scratch. R4d also supports multiple debugging flags for easier error detection. Refer https://github.com/simhyeon/r4d for detailed usage.")
@@ -313,7 +332,13 @@ impl Cli {
                 .takes_value(true)
                 .value_name("FILE")
                 .default_value(" ")
-                .about("Print signature to file."));
+                .about("Print signature to file."))
+            .arg(Arg::new("sigtype")
+                .long("sigtype")
+                .takes_value(true)
+                .value_name("SIG TYPE")
+                .default_value("all")
+                .about("Signature type to get"));
 
         app.get_matches()
     }
