@@ -79,7 +79,13 @@
 //! processor.add_custom_rules(vec![("test","a_src a_link","$a_src() -> $a_link()")]);
 //!
 //! // Add custom rules without any arguments
-//! processor.add_static_rules(vec![("test","TEST"),("lul","kekw")])
+//! processor.add_static_rules(vec![("test","TEST"),("lul","kekw")]);
+//!
+//! // Undefine rules
+//! processor.undefine_rules(vec!["name1", "name2"]);
+//!
+//! // Undefine only custom rules
+//! processor.undefine_custom_rules(vec!["name1", "name2"]);
 //! 
 //! // Process with inputs
 //! // This prints to desginated write destinations
@@ -112,7 +118,9 @@ use crate::error::RadError;
 use crate::logger::{Logger, LoggerLines};
 #[cfg(feature = "debug")]
 use crate::debugger::Debugger;
-use crate::models::{CommentType, MacroFragment, MacroMap, CustomMacro, RuleFile, UnbalancedChecker, WriteOption, LocalMacro};
+use crate::models::{CommentType, MacroFragment, MacroMap, CustomMacro, RuleFile, UnbalancedChecker, WriteOption, LocalMacro, FlowControl};
+#[cfg(feature = "signature")]
+use crate::models::SignatureType;
 #[cfg(feature = "hook")]
 use crate::hookmap::{HookMap, HookType};
 #[cfg(feature = "signature")]
@@ -164,6 +172,7 @@ pub(crate) struct ProcessorState {
     pub temp_target: (PathBuf,File), 
     pub comment_char : Option<char>,
     pub macro_char : Option<char>,
+    pub flow_control : FlowControl,
 }
 
 impl ProcessorState {
@@ -184,6 +193,7 @@ impl ProcessorState {
             temp_target,
             comment_char: None,
             macro_char: None,
+            flow_control: FlowControl::None,
         }
     }
 }
@@ -217,6 +227,11 @@ impl Processor {
         Self::new_processor(false)
     }
 
+    /// Clear custom macros
+    pub fn clear_custom_macros(&mut self) {
+        self.map.clear_custom_macros();
+    }
+
     /// Internal function to create Processor struct
     ///
     /// This creates a complete processor that can parse and create output without any extra
@@ -478,8 +493,13 @@ impl Processor {
     
     /// Get macro signatrue map
     #[cfg(feature = "signature")]
-    pub fn get_signature_map(&self) -> RadResult<SignatureMap> {
-        Ok(SignatureMap::new(self.map.get_signatures()))
+    pub fn get_signature_map(&self, sig_type : SignatureType) -> RadResult<SignatureMap> {
+        let signatures = match sig_type {
+            SignatureType::All => self.map.get_signatures(),
+            SignatureType::Default => self.map.get_default_signatures(),
+            SignatureType::Custom => self.map.get_custom_signatures(),
+        };
+        Ok(SignatureMap::new(signatures))
     }
 
     /// Print current permission status
@@ -605,6 +625,20 @@ impl Processor {
         Ok(())
     }
 
+    /// Remove rules from map
+    pub fn undefine_rules(&mut self, rules: Vec<impl AsRef<str>>) {
+        for name in rules {
+            self.map.undefine(name.as_ref());
+        }
+    }
+
+    /// Remove rules from map but only custom macro
+    pub fn undefine_custom_rules(&mut self, rules: Vec<impl AsRef<str>>) {
+        for name in rules {
+            self.map.undefine_custom(name.as_ref());
+        }
+    }
+
     #[cfg(feature = "hook")]
     /// Register a hook
     pub fn register_hook(&mut self, hook_type: HookType, target_macro: &str, invoke_macro: &str, target_count: usize, resetable: bool) -> RadResult<()> {
@@ -821,6 +855,12 @@ impl Processor {
         if let Some(line) = lines.next() {
             let line = line?;
 
+            match self.state.flow_control {
+                FlowControl::Escape => return Ok(ParseResult::Printable(line)),
+                FlowControl::Exit => return Err(RadError::Exit),
+                FlowControl::None => (),
+            }
+
             // Save to original
             #[cfg(feature = "debug")]
             self.debugger.write_to_original(&line)?;
@@ -1316,7 +1356,8 @@ impl Processor {
 
     fn lex_branch_end_frag_eval_result_error(&mut self, error : RadError) -> RadResult<()> {
         // this is equlvalent to conceptual if let not pattern
-        if let RadError::Panic = error{
+        // Log error when panic occured
+        if let RadError::Panic = error {
             // Do nothing
             ();
         } else {
@@ -1324,6 +1365,7 @@ impl Processor {
         }
 
         // If nopanic don't panic
+        // If not, re-throw err to caller
         if self.state.nopanic {
             Ok(())
         } else {
